from .center import CenterViewSet
from .csrf import csrf_token_view
from .gender import GenderViewSet
from .stats import (
    ExaminationStatsView,
    VideoSegmentStatsView,
    SensitiveMetaStatsView,
    GeneralStatsView,
)

from .upload_views import (
    UploadFileView,
    UploadStatusView,
)

__all__ = [
    "CenterViewSet",
    'csrf_token_view',

    # Gender view
    "GenderViewSet",

    # Stats views
    'ExaminationStatsView',
    'VideoSegmentStatsView',
    'SensitiveMetaStatsView',
    "GeneralStatsView",

    # Upload views
    'UploadFileView',
    'UploadStatusView',

]



# Generated by Django 6.0 on 2025-12-11 11:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0002_alter_rawpdfstate_options_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='examination',
            name='description_de',
        ),
        migrations.RemoveField(
            model_name='examination',
            name='description_en',
        ),
        migrations.RemoveField(
            model_name='examination',
            name='name_de',
        ),
        migrations.RemoveField(
            model_name='examination',
            name='name_en',
        ),
        migrations.RemoveField(
            model_name='finding',
            name='description_de',
        ),
        migrations.RemoveField(
            model_name='finding',
            name='description_en',
        ),
        migrations.RemoveField(
            model_name='finding',
            name='name_de',
        ),
        migrations.RemoveField(
            model_name='finding',
            name='name_en',
        ),
        migrations.RemoveField(
            model_name='findingclassification',
            name='description_de',
        ),
        migrations.RemoveField(
            model_name='findingclassification',
            name='description_en',
        ),
        migrations.RemoveField(
            model_name='findingclassification',
            name='name_de',
        ),
        migrations.RemoveField(
            model_name='findingclassification',
            name='name_en',
        ),
        migrations.RemoveField(
            model_name='findingclassificationchoice',
            name='description_de',
        ),
        migrations.RemoveField(
            model_name='findingclassificationchoice',
            name='description_en',
        ),
        migrations.RemoveField(
            model_name='findingclassificationchoice',
            name='name_de',
        ),
        migrations.RemoveField(
            model_name='findingclassificationchoice',
            name='name_en',
        ),
        migrations.RemoveField(
            model_name='findingintervention',
            name='description_de',
        ),
        migrations.RemoveField(
            model_name='findingintervention',
            name='description_en',
        ),
        migrations.RemoveField(
            model_name='findingintervention',
            name='name_de',
        ),
        migrations.RemoveField(
            model_name='findingintervention',
            name='name_en',
        ),
    ]



# Generated by Django 6.0 on 2025-12-11 15:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0005_alter_processinghistory_file_name_hash'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='processinghistory',
            name='content_type',
        ),
        migrations.RemoveField(
            model_name='processinghistory',
            name='file_name_hash',
        ),
        migrations.AddField(
            model_name='processinghistory',
            name='file_hash',
            field=models.CharField(blank=True, help_text='Content hash of the original file (e.g. video_hash/pdf_hash).', max_length=64, primary_key=True, serialize=False),
        ),
    ]



# Generated by Django 6.0 on 2025-12-11 15:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0006_remove_processinghistory_content_type_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='videofile',
            name='uuid',
        ),
    ]



# Generated by Django 6.0 on 2025-12-11 14:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0004_remove_processinghistory_id_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='processinghistory',
            name='file_name_hash',
            field=models.CharField(blank=True, help_text='SHA-256 hash of the processed file name.', max_length=64, primary_key=True, serialize=False),
        ),
    ]



# Generated by Django 6.0 on 2025-12-11 14:10

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('endoreg_db', '0003_remove_examination_description_de_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='processinghistory',
            name='id',
        ),
        migrations.AddField(
            model_name='processinghistory',
            name='file_name_hash',
            field=models.CharField(blank=True, editable=False, help_text='SHA-256 hash of the processed file name.', max_length=64, primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='processinghistory',
            name='content_type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='contenttypes.contenttype'),
        ),
        migrations.AlterField(
            model_name='processinghistory',
            name='object_id',
            field=models.PositiveBigIntegerField(blank=True, null=True),
        ),
    ]



# Generated by Django 6.0 on 2025-12-11 11:36

import django.core.validators
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('endoreg_db', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='rawpdfstate',
            options={'verbose_name': 'Raw report Processing State', 'verbose_name_plural': 'Raw report Processing States'},
        ),
        migrations.RemoveField(
            model_name='rawpdffile',
            name='anonymized',
        ),
        migrations.RemoveField(
            model_name='rawpdffile',
            name='anonymized_file',
        ),
        migrations.AddField(
            model_name='rawpdffile',
            name='processed_file',
            field=models.FileField(blank=True, null=True, upload_to='processed_reports_final', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['pdf'])]),
        ),
        migrations.AlterField(
            model_name='anonymexaminationreport',
            name='file',
            field=models.FileField(blank=True, null=True, upload_to='documents'),
        ),
        migrations.AlterField(
            model_name='anonymhistologyreport',
            name='file',
            field=models.FileField(blank=True, null=True, upload_to='documents'),
        ),
        migrations.AlterField(
            model_name='rawpdffile',
            name='file',
            field=models.FileField(upload_to='sensitive_reports', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['pdf'])]),
        ),
        migrations.AlterField(
            model_name='rawpdfstate',
            name='pdf_meta_extracted',
            field=models.BooleanField(default=False, help_text='True if report metadata has been extracted.'),
        ),
        migrations.AlterField(
            model_name='uploadjob',
            name='file',
            field=models.FileField(help_text='Uploaded file (report or video)', upload_to='uploads/%Y/%m/%d/'),
        ),
        migrations.AlterField(
            model_name='videofile',
            name='processed_file',
            field=models.FileField(blank=True, null=True, upload_to='processed_videos_final', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['mp4'])]),
        ),
        migrations.AlterField(
            model_name='videofile',
            name='raw_file',
            field=models.FileField(blank=True, null=True, upload_to='sensitive_videos', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['mp4'])]),
        ),
        migrations.CreateModel(
            name='ProcessingHistory',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('success', models.BooleanField(blank=True, default=False)),
                ('object_id', models.PositiveBigIntegerField()),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.contenttype')),
            ],
            options={
                'ordering': ['-created_at'],
            },
        ),
    ]
